@@ -1,7 +1,8 @@
-import helper
+from . import helper
 import timeit
 
 import sys
+
 sys.path.insert(0, ".")
 
 
