@@ -1,7 +1,7 @@
 #!/usr/bin/env python
 
 from __future__ import division
-from helper import unittest, PillowTestCase
+from .helper import unittest, PillowTestCase
 import sys
 from PIL import Image
 
@@ -9,11 +9,11 @@ min_iterations = 100
 max_iterations = 10000
 
 
-@unittest.skipIf(sys.platform.startswith('win32'), "requires Unix or macOS")
+@unittest.skipIf(sys.platform.startswith("win32"), "requires Unix or macOS")
 class TestImagingLeaks(PillowTestCase):
-
     def _get_mem_usage(self):
         from resource import getpagesize, getrusage, RUSAGE_SELF
+
         mem = getrusage(RUSAGE_SELF).ru_maxrss
         return mem * getpagesize() / 1024 / 1024
 
@@ -25,20 +25,22 @@ class TestImagingLeaks(PillowTestCase):
             if i < min_iterations:
                 mem_limit = mem + 1
                 continue
-            msg = 'memory usage limit exceeded after %d iterations' % (i + 1)
+            msg = "memory usage limit exceeded after %d iterations" % (i + 1)
             self.assertLessEqual(mem, mem_limit, msg)
 
     def test_leak_putdata(self):
-        im = Image.new('RGB', (25, 25))
-        self._test_leak(min_iterations, max_iterations,
-                        im.putdata, im.getdata())
+        im = Image.new("RGB", (25, 25))
+        self._test_leak(min_iterations, max_iterations, im.putdata, im.getdata())
 
     def test_leak_getlist(self):
-        im = Image.new('P', (25, 25))
-        self._test_leak(min_iterations, max_iterations,
-                        # Pass a new list at each iteration.
-                        lambda: im.point(range(256)))
+        im = Image.new("P", (25, 25))
+        self._test_leak(
+            min_iterations,
+            max_iterations,
+            # Pass a new list at each iteration.
+            lambda: im.point(range(256)),
+        )
 
 
-if __name__ == '__main__':
+if __name__ == "__main__":
     unittest.main()
