@@ -1,4 +1,4 @@
-from helper import unittest, PillowTestCase
+from .helper import unittest, PillowTestCase
 from PIL import Image
 
 TEST_FILE = "Tests/images/libtiff_segfault.tif"
@@ -15,5 +15,5 @@ class TestLibtiffSegfault(PillowTestCase):
             im.load()
 
 
-if __name__ == '__main__':
+if __name__ == "__main__":
     unittest.main()
