@@ -1,4 +1,4 @@
-from helper import unittest, PillowTestCase, hopper
+from .helper import PillowTestCase, hopper
 
 from PIL import Image
 
@@ -8,7 +8,6 @@ ORIGINAL_LIMIT = Image.MAX_IMAGE_PIXELS
 
 
 class TestDecompressionBomb(PillowTestCase):
-
     def tearDown(self):
         Image.MAX_IMAGE_PIXELS = ORIGINAL_LIMIT
 
@@ -33,20 +32,17 @@ class TestDecompressionBomb(PillowTestCase):
         Image.MAX_IMAGE_PIXELS = 128 * 128 - 1
         self.assertEqual(Image.MAX_IMAGE_PIXELS, 128 * 128 - 1)
 
-        self.assert_warning(Image.DecompressionBombWarning,
-                            Image.open, TEST_FILE)
+        self.assert_warning(Image.DecompressionBombWarning, Image.open, TEST_FILE)
 
     def test_exception(self):
         # Set limit to trigger exception on the test file
         Image.MAX_IMAGE_PIXELS = 64 * 128 - 1
         self.assertEqual(Image.MAX_IMAGE_PIXELS, 64 * 128 - 1)
 
-        self.assertRaises(Image.DecompressionBombError,
-                          lambda: Image.open(TEST_FILE))
+        self.assertRaises(Image.DecompressionBombError, lambda: Image.open(TEST_FILE))
 
 
 class TestDecompressionCrop(PillowTestCase):
-
     def setUp(self):
         self.src = hopper()
         Image.MAX_IMAGE_PIXELS = self.src.height * self.src.width * 4 - 1
@@ -58,21 +54,17 @@ class TestDecompressionCrop(PillowTestCase):
         # Crops can extend the extents, therefore we should have the
         # same decompression bomb warnings on them.
         box = (0, 0, self.src.width * 2, self.src.height * 2)
-        self.assert_warning(Image.DecompressionBombWarning,
-                            self.src.crop, box)
+        self.assert_warning(Image.DecompressionBombWarning, self.src.crop, box)
 
     def test_crop_decompression_checks(self):
 
         im = Image.new("RGB", (100, 100))
 
-        good_values = ((-9999, -9999, -9990, -9990),
-                       (-999, -999, -990, -990))
+        good_values = ((-9999, -9999, -9990, -9990), (-999, -999, -990, -990))
 
-        warning_values = ((-160, -160, 99, 99),
-                          (160, 160, -99, -99))
+        warning_values = ((-160, -160, 99, 99), (160, 160, -99, -99))
 
-        error_values = ((-99909, -99990, 99999, 99999),
-                        (99909, 99990, -99999, -99999))
+        error_values = ((-99909, -99990, 99999, 99999), (99909, 99990, -99999, -99999))
 
         for value in good_values:
             self.assertEqual(im.crop(value).size, (9, 9))
@@ -83,7 +75,3 @@ class TestDecompressionCrop(PillowTestCase):
         for value in error_values:
             with self.assertRaises(Image.DecompressionBombError):
                 im.crop(value)
-
-
-if __name__ == '__main__':
-    unittest.main()
