@@ -1,4 +1,4 @@
-from helper import unittest, PillowTestCase
+from .helper import PillowTestCase
 
 from PIL import Image, CurImagePlugin
 
@@ -6,7 +6,6 @@ TEST_FILE = "Tests/images/deerstalker.cur"
 
 
 class TestFileCur(PillowTestCase):
-
     def test_sanity(self):
         im = Image.open(TEST_FILE)
 
@@ -20,17 +19,11 @@ class TestFileCur(PillowTestCase):
     def test_invalid_file(self):
         invalid_file = "Tests/images/flower.jpg"
 
-        self.assertRaises(SyntaxError,
-                          lambda: CurImagePlugin.CurImageFile(invalid_file))
+        self.assertRaises(SyntaxError, CurImagePlugin.CurImageFile, invalid_file)
 
         no_cursors_file = "Tests/images/no_cursors.cur"
 
         cur = CurImagePlugin.CurImageFile(TEST_FILE)
-        cur.fp = open(no_cursors_file, "rb")
-        self.assertRaises(TypeError, cur._open)
-
-
-if __name__ == '__main__':
-    unittest.main()
-
-# End of file
+        cur.fp.close()
+        with open(no_cursors_file, "rb") as cur.fp:
+            self.assertRaises(TypeError, cur._open)
