@@ -1,4 +1,4 @@
-from helper import unittest, PillowTestCase
+from .helper import unittest, PillowTestCase
 
 try:
     from PIL import FpxImagePlugin
@@ -10,18 +10,11 @@ else:
 
 @unittest.skipUnless(olefile_installed, "olefile package not installed")
 class TestFileFpx(PillowTestCase):
-
     def test_invalid_file(self):
         # Test an invalid OLE file
         invalid_file = "Tests/images/flower.jpg"
-        self.assertRaises(SyntaxError,
-                          FpxImagePlugin.FpxImageFile, invalid_file)
+        self.assertRaises(SyntaxError, FpxImagePlugin.FpxImageFile, invalid_file)
 
         # Test a valid OLE file, but not an FPX file
         ole_file = "Tests/images/test-ole-file.doc"
-        self.assertRaises(SyntaxError,
-                          FpxImagePlugin.FpxImageFile, ole_file)
-
-
-if __name__ == '__main__':
-    unittest.main()
+        self.assertRaises(SyntaxError, FpxImagePlugin.FpxImageFile, ole_file)
