@@ -1,4 +1,4 @@
-from helper import unittest, PillowTestCase, hopper
+from .helper import unittest, PillowTestCase, hopper
 
 from PIL import Image, MspImagePlugin
 
@@ -10,13 +10,12 @@ YA_EXTRA_DIR = "Tests/images/msp"
 
 
 class TestFileMsp(PillowTestCase):
-
     def test_sanity(self):
-        file = self.tempfile("temp.msp")
+        test_file = self.tempfile("temp.msp")
 
-        hopper("1").save(file)
+        hopper("1").save(test_file)
 
-        im = Image.open(file)
+        im = Image.open(test_file)
         im.load()
         self.assertEqual(im.mode, "1")
         self.assertEqual(im.size, (128, 128))
@@ -25,8 +24,7 @@ class TestFileMsp(PillowTestCase):
     def test_invalid_file(self):
         invalid_file = "Tests/images/flower.jpg"
 
-        self.assertRaises(SyntaxError,
-                          MspImagePlugin.MspImageFile, invalid_file)
+        self.assertRaises(SyntaxError, MspImagePlugin.MspImageFile, invalid_file)
 
     def test_bad_checksum(self):
         # Arrange
@@ -34,8 +32,7 @@ class TestFileMsp(PillowTestCase):
         bad_checksum = "Tests/images/hopper_bad_checksum.msp"
 
         # Act / Assert
-        self.assertRaises(SyntaxError,
-                          MspImagePlugin.MspImageFile, bad_checksum)
+        self.assertRaises(SyntaxError, MspImagePlugin.MspImageFile, bad_checksum)
 
     def test_open_windows_v1(self):
         # Arrange
@@ -51,25 +48,26 @@ class TestFileMsp(PillowTestCase):
             target = Image.open(target_path)
             self.assert_image_equal(im, target)
 
-    @unittest.skipIf(not os.path.exists(EXTRA_DIR),
-                     "Extra image files not installed")
+    @unittest.skipIf(not os.path.exists(EXTRA_DIR), "Extra image files not installed")
     def test_open_windows_v2(self):
 
-        files = (os.path.join(EXTRA_DIR, f) for f in os.listdir(EXTRA_DIR)
-                 if os.path.splitext(f)[1] == '.msp')
+        files = (
+            os.path.join(EXTRA_DIR, f)
+            for f in os.listdir(EXTRA_DIR)
+            if os.path.splitext(f)[1] == ".msp"
+        )
         for path in files:
-            self._assert_file_image_equal(path,
-                                          path.replace('.msp', '.png'))
+            self._assert_file_image_equal(path, path.replace(".msp", ".png"))
 
-    @unittest.skipIf(not os.path.exists(YA_EXTRA_DIR),
-                     "Even More Extra image files not installed")
+    @unittest.skipIf(
+        not os.path.exists(YA_EXTRA_DIR), "Even More Extra image files not installed"
+    )
     def test_msp_v2(self):
         for f in os.listdir(YA_EXTRA_DIR):
-            if '.MSP' not in f:
+            if ".MSP" not in f:
                 continue
             path = os.path.join(YA_EXTRA_DIR, f)
-            self._assert_file_image_equal(path,
-                                          path.replace('.MSP', '.png'))
+            self._assert_file_image_equal(path, path.replace(".MSP", ".png"))
 
     def test_cannot_save_wrong_mode(self):
         # Arrange
@@ -78,7 +76,3 @@ class TestFileMsp(PillowTestCase):
 
         # Act/Assert
         self.assertRaises(IOError, im.save, filename)
-
-
-if __name__ == '__main__':
-    unittest.main()
