@@ -1,11 +1,10 @@
-from helper import unittest, PillowTestCase
+from .helper import PillowTestCase
 from PIL import Image
 
 
 class TestFilePcd(PillowTestCase):
-
     def test_load_raw(self):
-        im = Image.open('Tests/images/hopper.pcd')
+        im = Image.open("Tests/images/hopper.pcd")
         im.load()  # should not segfault.
 
         # Note that this image was created with a resized hopper
@@ -16,7 +15,3 @@ class TestFilePcd(PillowTestCase):
 
         # target = hopper().resize((768,512))
         # self.assert_image_similar(im, target, 10)
-
-
-if __name__ == '__main__':
-    unittest.main()
