@@ -1,4 +1,4 @@
-from helper import hopper, unittest, PillowTestCase
+from .helper import hopper, PillowTestCase
 
 from PIL import Image, PixarImagePlugin
 
@@ -6,7 +6,6 @@ TEST_FILE = "Tests/images/hopper.pxr"
 
 
 class TestFilePixar(PillowTestCase):
-
     def test_sanity(self):
         im = Image.open(TEST_FILE)
         im.load()
@@ -21,10 +20,4 @@ class TestFilePixar(PillowTestCase):
     def test_invalid_file(self):
         invalid_file = "Tests/images/flower.jpg"
 
-        self.assertRaises(
-            SyntaxError,
-            PixarImagePlugin.PixarImageFile, invalid_file)
-
-
-if __name__ == '__main__':
-    unittest.main()
+        self.assertRaises(SyntaxError, PixarImagePlugin.PixarImageFile, invalid_file)
