@@ -1,4 +1,4 @@
-from helper import unittest, PillowTestCase
+from .helper import PillowTestCase
 
 from PIL import Image, TarIO
 
@@ -9,15 +9,14 @@ TEST_TAR_FILE = "Tests/images/hopper.tar"
 
 
 class TestFileTar(PillowTestCase):
-
     def setUp(self):
         if "zip_decoder" not in codecs and "jpeg_decoder" not in codecs:
             self.skipTest("neither jpeg nor zip support available")
 
     def test_sanity(self):
         for codec, test_path, format in [
-            ['zip_decoder', 'hopper.png', 'PNG'],
-            ['jpeg_decoder', 'hopper.jpg', 'JPEG']
+            ["zip_decoder", "hopper.png", "PNG"],
+            ["jpeg_decoder", "hopper.jpg", "JPEG"],
         ]:
             if codec in codecs:
                 tar = TarIO.TarIO(TEST_TAR_FILE, test_path)
@@ -28,13 +27,9 @@ class TestFileTar(PillowTestCase):
                 self.assertEqual(im.format, format)
 
     def test_close(self):
-        tar = TarIO.TarIO(TEST_TAR_FILE, 'hopper.jpg')
+        tar = TarIO.TarIO(TEST_TAR_FILE, "hopper.jpg")
         tar.close()
 
     def test_contextmanager(self):
-        with TarIO.TarIO(TEST_TAR_FILE, 'hopper.jpg'):
+        with TarIO.TarIO(TEST_TAR_FILE, "hopper.jpg"):
             pass
-
-
-if __name__ == '__main__':
-    unittest.main()
