@@ -2,7 +2,7 @@ import os
 from glob import glob
 from itertools import product
 
-from helper import unittest, PillowTestCase
+from .helper import PillowTestCase
 
 from PIL import Image
 
@@ -16,16 +16,13 @@ class TestFileTga(PillowTestCase):
     _MODES = ("L", "LA", "P", "RGB", "RGBA")
     _ORIGINS = ("tl", "bl")
 
-    _ORIGIN_TO_ORIENTATION = {
-        "tl": 1,
-        "bl": -1
-    }
+    _ORIGIN_TO_ORIENTATION = {"tl": 1, "bl": -1}
 
     def test_sanity(self):
         for mode in self._MODES:
             png_paths = glob(
-                os.path.join(
-                    _TGA_DIR_COMMON, "*x*_{}.png".format(mode.lower())))
+                os.path.join(_TGA_DIR_COMMON, "*x*_{}.png".format(mode.lower()))
+            )
 
             for png_path in png_paths:
                 reference_im = Image.open(png_path)
@@ -34,19 +31,22 @@ class TestFileTga(PillowTestCase):
                 path_no_ext = os.path.splitext(png_path)[0]
                 for origin, rle in product(self._ORIGINS, (True, False)):
                     tga_path = "{}_{}_{}.tga".format(
-                        path_no_ext, origin, "rle" if rle else "raw")
+                        path_no_ext, origin, "rle" if rle else "raw"
+                    )
 
                     original_im = Image.open(tga_path)
+                    self.assertEqual(original_im.format, "TGA")
+                    self.assertEqual(original_im.get_format_mimetype(), "image/x-tga")
                     if rle:
-                        self.assertEqual(
-                            original_im.info["compression"], "tga_rle")
+                        self.assertEqual(original_im.info["compression"], "tga_rle")
                     self.assertEqual(
                         original_im.info["orientation"],
-                        self._ORIGIN_TO_ORIENTATION[origin])
+                        self._ORIGIN_TO_ORIENTATION[origin],
+                    )
                     if mode == "P":
                         self.assertEqual(
-                            original_im.getpalette(),
-                            reference_im.getpalette())
+                            original_im.getpalette(), reference_im.getpalette()
+                        )
 
                     self.assert_image_equal(original_im, reference_im)
 
@@ -60,14 +60,15 @@ class TestFileTga(PillowTestCase):
                     if rle:
                         self.assertEqual(
                             saved_im.info["compression"],
-                            original_im.info["compression"])
+                            original_im.info["compression"],
+                        )
                     self.assertEqual(
-                        saved_im.info["orientation"],
-                        original_im.info["orientation"])
+                        saved_im.info["orientation"], original_im.info["orientation"]
+                    )
                     if mode == "P":
                         self.assertEqual(
-                            saved_im.getpalette(),
-                            original_im.getpalette())
+                            saved_im.getpalette(), original_im.getpalette()
+                        )
 
                     self.assert_image_equal(saved_im, original_im)
 
@@ -126,8 +127,7 @@ class TestFileTga(PillowTestCase):
 
         # Save with custom id section greater than 255 characters
         id_section = b"Test content" * 25
-        self.assert_warning(UserWarning,
-                            lambda: im.save(out, id_section=id_section))
+        self.assert_warning(UserWarning, lambda: im.save(out, id_section=id_section))
         test_im = Image.open(out)
         self.assertEqual(test_im.info["id_section"], id_section[:255])
 
@@ -189,19 +189,13 @@ class TestFileTga(PillowTestCase):
         in_file = "Tests/images/la.tga"
         im = Image.open(in_file)
         self.assertEqual(im.mode, "LA")
-        self.assertEqual(
-            im.getchannel("A").getcolors()[0][0], num_transparent)
+        self.assertEqual(im.getchannel("A").getcolors()[0][0], num_transparent)
 
         out = self.tempfile("temp.tga")
         im.save(out)
 
         test_im = Image.open(out)
         self.assertEqual(test_im.mode, "LA")
-        self.assertEqual(
-            test_im.getchannel("A").getcolors()[0][0], num_transparent)
+        self.assertEqual(test_im.getchannel("A").getcolors()[0][0], num_transparent)
 
         self.assert_image_equal(im, test_im)
-
-
-if __name__ == '__main__':
-    unittest.main()
