@@ -1,4 +1,4 @@
-from helper import unittest, PillowTestCase
+from .helper import PillowTestCase
 
 from PIL import FontFile, BdfFontFile
 
@@ -6,7 +6,6 @@ filename = "Tests/images/courB08.bdf"
 
 
 class TestFontBdf(PillowTestCase):
-
     def test_sanity(self):
 
         with open(filename, "rb") as test_file:
@@ -18,7 +17,3 @@ class TestFontBdf(PillowTestCase):
     def test_invalid_file(self):
         with open("Tests/images/flower.jpg", "rb") as fp:
             self.assertRaises(SyntaxError, BdfFontFile.BdfFontFile, fp)
-
-
-if __name__ == '__main__':
-    unittest.main()
