@@ -1,4 +1,4 @@
-from helper import unittest, PillowTestCase, hopper
+from .helper import PillowTestCase, hopper
 
 from PIL import Image
 
@@ -6,7 +6,6 @@ import copy
 
 
 class TestImageCopy(PillowTestCase):
-
     def test_copy(self):
         croppedCoordinates = (10, 10, 20, 20)
         croppedSize = (10, 10)
@@ -36,11 +35,7 @@ class TestImageCopy(PillowTestCase):
             self.assertEqual(out.size, croppedSize)
 
     def test_copy_zero(self):
-        im = Image.new('RGB', (0, 0))
+        im = Image.new("RGB", (0, 0))
         out = im.copy()
         self.assertEqual(out.mode, im.mode)
         self.assertEqual(out.size, im.size)
-
-
-if __name__ == '__main__':
-    unittest.main()
