@@ -1,12 +1,11 @@
 import math
 
-from helper import unittest, PillowTestCase, hopper
+from .helper import PillowTestCase, hopper
 
 from PIL import Image
 
 
 class TestImageTransform(PillowTestCase):
-
     def test_sanity(self):
         from PIL import ImageTransform
 
@@ -24,54 +23,61 @@ class TestImageTransform(PillowTestCase):
         im.transform((100, 100), transform)
 
     def test_extent(self):
-        im = hopper('RGB')
+        im = hopper("RGB")
         (w, h) = im.size
+        # fmt: off
         transformed = im.transform(im.size, Image.EXTENT,
                                    (0, 0,
                                     w//2, h//2),  # ul -> lr
                                    Image.BILINEAR)
+        # fmt: on
 
-        scaled = im.resize((w*2, h*2), Image.BILINEAR).crop((0, 0, w, h))
+        scaled = im.resize((w * 2, h * 2), Image.BILINEAR).crop((0, 0, w, h))
 
         # undone -- precision?
         self.assert_image_similar(transformed, scaled, 23)
 
     def test_quad(self):
         # one simple quad transform, equivalent to scale & crop upper left quad
-        im = hopper('RGB')
+        im = hopper("RGB")
         (w, h) = im.size
+        # fmt: off
         transformed = im.transform(im.size, Image.QUAD,
                                    (0, 0, 0, h//2,
                                     # ul -> ccw around quad:
                                     w//2, h//2, w//2, 0),
                                    Image.BILINEAR)
+        # fmt: on
 
-        scaled = im.transform((w, h), Image.AFFINE,
-                              (.5, 0, 0, 0, .5, 0),
-                              Image.BILINEAR)
+        scaled = im.transform(
+            (w, h), Image.AFFINE, (0.5, 0, 0, 0, 0.5, 0), Image.BILINEAR
+        )
 
         self.assert_image_equal(transformed, scaled)
 
     def test_fill(self):
         for mode, pixel in [
-            ['RGB', (255, 0, 0)],
-            ['RGBA', (255, 0, 0, 255)],
-            ['LA', (76, 0)]
+            ["RGB", (255, 0, 0)],
+            ["RGBA", (255, 0, 0, 255)],
+            ["LA", (76, 0)],
         ]:
             im = hopper(mode)
             (w, h) = im.size
-            transformed = im.transform(im.size, Image.EXTENT,
-                                       (0, 0,
-                                        w*2, h*2),
-                                       Image.BILINEAR,
-                                       fillcolor='red')
+            transformed = im.transform(
+                im.size,
+                Image.EXTENT,
+                (0, 0, w * 2, h * 2),
+                Image.BILINEAR,
+                fillcolor="red",
+            )
 
-            self.assertEqual(transformed.getpixel((w-1, h-1)), pixel)
+            self.assertEqual(transformed.getpixel((w - 1, h - 1)), pixel)
 
     def test_mesh(self):
         # this should be a checkerboard of halfsized hoppers in ul, lr
-        im = hopper('RGBA')
+        im = hopper("RGBA")
         (w, h) = im.size
+        # fmt: off
         transformed = im.transform(im.size, Image.MESH,
                                    [((0, 0, w//2, h//2),  # box
                                     (0, 0, 0, h,
@@ -80,54 +86,50 @@ class TestImageTransform(PillowTestCase):
                                     (0, 0, 0, h,
                                      w, h, w, 0))],  # ul -> ccw around quad
                                    Image.BILINEAR)
+        # fmt: on
 
-        scaled = im.transform((w//2, h//2), Image.AFFINE,
-                              (2, 0, 0, 0, 2, 0),
-                              Image.BILINEAR)
+        scaled = im.transform(
+            (w // 2, h // 2), Image.AFFINE, (2, 0, 0, 0, 2, 0), Image.BILINEAR
+        )
 
-        checker = Image.new('RGBA', im.size)
+        checker = Image.new("RGBA", im.size)
         checker.paste(scaled, (0, 0))
-        checker.paste(scaled, (w//2, h//2))
+        checker.paste(scaled, (w // 2, h // 2))
 
         self.assert_image_equal(transformed, checker)
 
         # now, check to see that the extra area is (0, 0, 0, 0)
-        blank = Image.new('RGBA', (w//2, h//2), (0, 0, 0, 0))
+        blank = Image.new("RGBA", (w // 2, h // 2), (0, 0, 0, 0))
 
-        self.assert_image_equal(blank, transformed.crop((w//2, 0, w, h//2)))
-        self.assert_image_equal(blank, transformed.crop((0, h//2, w//2, h)))
+        self.assert_image_equal(blank, transformed.crop((w // 2, 0, w, h // 2)))
+        self.assert_image_equal(blank, transformed.crop((0, h // 2, w // 2, h)))
 
     def _test_alpha_premult(self, op):
         # create image with half white, half black,
         # with the black half transparent.
         # do op,
         # there should be no darkness in the white section.
-        im = Image.new('RGBA', (10, 10), (0, 0, 0, 0))
-        im2 = Image.new('RGBA', (5, 10), (255, 255, 255, 255))
+        im = Image.new("RGBA", (10, 10), (0, 0, 0, 0))
+        im2 = Image.new("RGBA", (5, 10), (255, 255, 255, 255))
         im.paste(im2, (0, 0))
 
         im = op(im, (40, 10))
-        im_background = Image.new('RGB', (40, 10), (255, 255, 255))
+        im_background = Image.new("RGB", (40, 10), (255, 255, 255))
         im_background.paste(im, (0, 0), im)
 
         hist = im_background.histogram()
-        self.assertEqual(40*10, hist[-1])
+        self.assertEqual(40 * 10, hist[-1])
 
     def test_alpha_premult_resize(self):
-
         def op(im, sz):
             return im.resize(sz, Image.BILINEAR)
 
         self._test_alpha_premult(op)
 
     def test_alpha_premult_transform(self):
-
         def op(im, sz):
             (w, h) = im.size
-            return im.transform(sz, Image.EXTENT,
-                                (0, 0,
-                                 w, h),
-                                Image.BILINEAR)
+            return im.transform(sz, Image.EXTENT, (0, 0, w, h), Image.BILINEAR)
 
         self._test_alpha_premult(op)
 
@@ -146,10 +148,7 @@ class TestImageTransform(PillowTestCase):
         # Running by default, but I'd totally understand not doing it in
         # the future
 
-        pattern = [
-            Image.new('RGBA', (1024, 1024), (a, a, a, a))
-            for a in range(1, 65)
-        ]
+        pattern = [Image.new("RGBA", (1024, 1024), (a, a, a, a)) for a in range(1, 65)]
 
         # Yeah. Watch some JIT optimize this out.
         pattern = None  # noqa: F841
@@ -160,22 +159,41 @@ class TestImageTransform(PillowTestCase):
         im = hopper()
         self.assertRaises(ValueError, im.transform, (100, 100), None)
 
+    def test_unknown_resampling_filter(self):
+        im = hopper()
+        (w, h) = im.size
+        for resample in (Image.BOX, "unknown"):
+            self.assertRaises(
+                ValueError,
+                im.transform,
+                (100, 100),
+                Image.EXTENT,
+                (0, 0, w, h),
+                resample,
+            )
+
 
 class TestImageTransformAffine(PillowTestCase):
     transform = Image.AFFINE
 
     def _test_image(self):
-        im = hopper('RGB')
+        im = hopper("RGB")
         return im.crop((10, 20, im.width - 10, im.height - 20))
 
     def _test_rotate(self, deg, transpose):
         im = self._test_image()
 
-        angle = - math.radians(deg)
+        angle = -math.radians(deg)
         matrix = [
-            round(math.cos(angle), 15), round(math.sin(angle), 15), 0.0,
-            round(-math.sin(angle), 15), round(math.cos(angle), 15), 0.0,
-            0, 0]
+            round(math.cos(angle), 15),
+            round(math.sin(angle), 15),
+            0.0,
+            round(-math.sin(angle), 15),
+            round(math.cos(angle), 15),
+            0.0,
+            0,
+            0,
+        ]
         matrix[2] = (1 - matrix[0] - matrix[1]) * im.width / 2
         matrix[5] = (1 - matrix[3] - matrix[4]) * im.height / 2
 
@@ -185,8 +203,9 @@ class TestImageTransformAffine(PillowTestCase):
             transposed = im
 
         for resample in [Image.NEAREST, Image.BILINEAR, Image.BICUBIC]:
-            transformed = im.transform(transposed.size, self.transform,
-                                       matrix, resample)
+            transformed = im.transform(
+                transposed.size, self.transform, matrix, resample
+            )
             self.assert_image_equal(transposed, transformed)
 
     def test_rotate_0_deg(self):
@@ -205,21 +224,18 @@ class TestImageTransformAffine(PillowTestCase):
         im = self._test_image()
 
         size_up = int(round(im.width * scale)), int(round(im.height * scale))
-        matrix_up = [
-            1 / scale, 0, 0,
-            0, 1 / scale, 0,
-            0, 0]
-        matrix_down = [
-            scale, 0, 0,
-            0, scale, 0,
-            0, 0]
+        matrix_up = [1 / scale, 0, 0, 0, 1 / scale, 0, 0, 0]
+        matrix_down = [scale, 0, 0, 0, scale, 0, 0, 0]
 
-        for resample, epsilon in [(Image.NEAREST, 0),
-                                  (Image.BILINEAR, 2), (Image.BICUBIC, 1)]:
-            transformed = im.transform(
-                size_up, self.transform, matrix_up, resample)
+        for resample, epsilon in [
+            (Image.NEAREST, 0),
+            (Image.BILINEAR, 2),
+            (Image.BICUBIC, 1),
+        ]:
+            transformed = im.transform(size_up, self.transform, matrix_up, resample)
             transformed = transformed.transform(
-                im.size, self.transform, matrix_down, resample)
+                im.size, self.transform, matrix_down, resample
+            )
             self.assert_image_similar(transformed, im, epsilon * epsilonscale)
 
     def test_resize_1_1x(self):
@@ -241,28 +257,25 @@ class TestImageTransformAffine(PillowTestCase):
         im = self._test_image()
 
         size_up = int(round(im.width + x)), int(round(im.height + y))
-        matrix_up = [
-            1, 0, -x,
-            0, 1, -y,
-            0, 0]
-        matrix_down = [
-            1, 0, x,
-            0, 1, y,
-            0, 0]
+        matrix_up = [1, 0, -x, 0, 1, -y, 0, 0]
+        matrix_down = [1, 0, x, 0, 1, y, 0, 0]
 
-        for resample, epsilon in [(Image.NEAREST, 0),
-                                  (Image.BILINEAR, 1.5), (Image.BICUBIC, 1)]:
-            transformed = im.transform(
-                size_up, self.transform, matrix_up, resample)
+        for resample, epsilon in [
+            (Image.NEAREST, 0),
+            (Image.BILINEAR, 1.5),
+            (Image.BICUBIC, 1),
+        ]:
+            transformed = im.transform(size_up, self.transform, matrix_up, resample)
             transformed = transformed.transform(
-                im.size, self.transform, matrix_down, resample)
+                im.size, self.transform, matrix_down, resample
+            )
             self.assert_image_similar(transformed, im, epsilon * epsilonscale)
 
     def test_translate_0_1(self):
-        self._test_translate(.1, 0, 3.7)
+        self._test_translate(0.1, 0, 3.7)
 
     def test_translate_0_6(self):
-        self._test_translate(.6, 0, 9.1)
+        self._test_translate(0.6, 0, 9.1)
 
     def test_translate_50(self):
         self._test_translate(50, 50, 0)
@@ -271,7 +284,3 @@ class TestImageTransformAffine(PillowTestCase):
 class TestImageTransformPerspective(TestImageTransformAffine):
     # Repeat all tests for AFFINE transformations with PERSPECTIVE
     transform = Image.PERSPECTIVE
-
-
-if __name__ == '__main__':
-    unittest.main()
