@@ -1,11 +1,10 @@
-from helper import unittest, PillowTestCase, hopper
+from .helper import PillowTestCase, hopper
 
 from PIL import Image
 from PIL import ImageEnhance
 
 
 class TestImageEnhance(PillowTestCase):
-
     def test_sanity(self):
 
         # FIXME: assert_image
@@ -23,10 +22,10 @@ class TestImageEnhance(PillowTestCase):
 
     def _half_transparent_image(self):
         # returns an image, half transparent, half solid
-        im = hopper('RGB')
+        im = hopper("RGB")
 
-        transparent = Image.new('L', im.size, 0)
-        solid = Image.new('L', (im.size[0]//2, im.size[1]), 255)
+        transparent = Image.new("L", im.size, 0)
+        solid = Image.new("L", (im.size[0] // 2, im.size[1]), 255)
         transparent.paste(solid, (0, 0))
         im.putalpha(transparent)
 
@@ -34,8 +33,11 @@ class TestImageEnhance(PillowTestCase):
 
     def _check_alpha(self, im, original, op, amount):
         self.assertEqual(im.getbands(), original.getbands())
-        self.assert_image_equal(im.getchannel('A'), original.getchannel('A'),
-                                "Diff on %s: %s" % (op, amount))
+        self.assert_image_equal(
+            im.getchannel("A"),
+            original.getchannel("A"),
+            "Diff on %s: %s" % (op, amount),
+        )
 
     def test_alpha(self):
         # Issue https://github.com/python-pillow/Pillow/issues/899
@@ -43,12 +45,11 @@ class TestImageEnhance(PillowTestCase):
 
         original = self._half_transparent_image()
 
-        for op in ['Color', 'Brightness', 'Contrast', 'Sharpness']:
+        for op in ["Color", "Brightness", "Contrast", "Sharpness"]:
             for amount in [0, 0.5, 1.0]:
                 self._check_alpha(
                     getattr(ImageEnhance, op)(original).enhance(amount),
-                    original, op, amount)
-
-
-if __name__ == '__main__':
-    unittest.main()
+                    original,
+                    op,
+                    amount,
+                )
