@@ -1,4 +1,4 @@
-from helper import unittest, PillowTestCase
+from .helper import PillowTestCase
 
 import sys
 import subprocess
@@ -7,34 +7,37 @@ try:
     from PIL import ImageGrab
 
     class TestImageGrab(PillowTestCase):
-
         def test_grab(self):
-            im = ImageGrab.grab()
-            self.assert_image(im, im.mode, im.size)
+            for im in [ImageGrab.grab(), ImageGrab.grab(include_layered_windows=True)]:
+                self.assert_image(im, im.mode, im.size)
 
         def test_grabclipboard(self):
             if sys.platform == "darwin":
-                subprocess.call(['screencapture', '-cx'])
+                subprocess.call(["screencapture", "-cx"])
             else:
-                p = subprocess.Popen(['powershell', '-command', '-'],
-                                     stdin=subprocess.PIPE)
-                p.stdin.write(b'''[Reflection.Assembly]::LoadWithPartialName("System.Drawing")
+                p = subprocess.Popen(
+                    ["powershell", "-command", "-"], stdin=subprocess.PIPE
+                )
+                p.stdin.write(
+                    b"""[Reflection.Assembly]::LoadWithPartialName("System.Drawing")
 [Reflection.Assembly]::LoadWithPartialName("System.Windows.Forms")
 $bmp = New-Object Drawing.Bitmap 200, 200
-[Windows.Forms.Clipboard]::SetImage($bmp)''')
+[Windows.Forms.Clipboard]::SetImage($bmp)"""
+                )
                 p.communicate()
 
             im = ImageGrab.grabclipboard()
             self.assert_image(im, im.mode, im.size)
 
+
 except ImportError:
+
     class TestImageGrab(PillowTestCase):
         def test_skip(self):
             self.skipTest("ImportError")
 
 
 class TestImageGrabImport(PillowTestCase):
-
     def test_import(self):
         # Arrange
         exception = None
@@ -42,6 +45,7 @@ class TestImageGrabImport(PillowTestCase):
         # Act
         try:
             from PIL import ImageGrab
+
             ImageGrab.__name__  # dummy to prevent Pyflakes warning
         except Exception as e:
             exception = e
@@ -51,9 +55,4 @@ class TestImageGrabImport(PillowTestCase):
             self.assertIsNone(exception)
         else:
             self.assertIsInstance(exception, ImportError)
-            self.assertEqual(str(exception),
-                             "ImageGrab is macOS and Windows only")
-
-
-if __name__ == '__main__':
-    unittest.main()
+            self.assertEqual(str(exception), "ImageGrab is macOS and Windows only")
