@@ -1,11 +1,10 @@
-from helper import unittest, PillowTestCase, hopper
+from .helper import PillowTestCase, hopper
 
 from PIL import Image
 from PIL import ImageStat
 
 
 class TestImageStat(PillowTestCase):
-
     def test_sanity(self):
 
         im = hopper()
@@ -48,14 +47,10 @@ class TestImageStat(PillowTestCase):
         st = ImageStat.Stat(im)
 
         self.assertEqual(st.extrema[0], (128, 128))
-        self.assertEqual(st.sum[0], 128**3)
-        self.assertEqual(st.sum2[0], 128**4)
+        self.assertEqual(st.sum[0], 128 ** 3)
+        self.assertEqual(st.sum2[0], 128 ** 4)
         self.assertEqual(st.mean[0], 128)
         self.assertEqual(st.median[0], 128)
         self.assertEqual(st.rms[0], 128)
         self.assertEqual(st.var[0], 0)
         self.assertEqual(st.stddev[0], 0)
-
-
-if __name__ == '__main__':
-    unittest.main()
