@@ -1,4 +1,4 @@
-from helper import unittest, PillowTestCase, hopper
+from .helper import PillowTestCase, hopper
 from PIL import Image, ImageWin
 
 import sys
@@ -7,33 +7,33 @@ from io import BytesIO
 
 # see https://github.com/python-pillow/Pillow/pull/1431#issuecomment-144692652
 
-if sys.platform.startswith('win32'):
+if sys.platform.startswith("win32"):
     import ctypes.wintypes
 
     class BITMAPFILEHEADER(ctypes.Structure):
         _pack_ = 2
         _fields_ = [
-            ('bfType', ctypes.wintypes.WORD),
-            ('bfSize', ctypes.wintypes.DWORD),
-            ('bfReserved1', ctypes.wintypes.WORD),
-            ('bfReserved2', ctypes.wintypes.WORD),
-            ('bfOffBits', ctypes.wintypes.DWORD),
+            ("bfType", ctypes.wintypes.WORD),
+            ("bfSize", ctypes.wintypes.DWORD),
+            ("bfReserved1", ctypes.wintypes.WORD),
+            ("bfReserved2", ctypes.wintypes.WORD),
+            ("bfOffBits", ctypes.wintypes.DWORD),
         ]
 
     class BITMAPINFOHEADER(ctypes.Structure):
         _pack_ = 2
         _fields_ = [
-            ('biSize', ctypes.wintypes.DWORD),
-            ('biWidth', ctypes.wintypes.LONG),
-            ('biHeight', ctypes.wintypes.LONG),
-            ('biPlanes', ctypes.wintypes.WORD),
-            ('biBitCount', ctypes.wintypes.WORD),
-            ('biCompression', ctypes.wintypes.DWORD),
-            ('biSizeImage', ctypes.wintypes.DWORD),
-            ('biXPelsPerMeter', ctypes.wintypes.LONG),
-            ('biYPelsPerMeter', ctypes.wintypes.LONG),
-            ('biClrUsed', ctypes.wintypes.DWORD),
-            ('biClrImportant', ctypes.wintypes.DWORD),
+            ("biSize", ctypes.wintypes.DWORD),
+            ("biWidth", ctypes.wintypes.LONG),
+            ("biHeight", ctypes.wintypes.LONG),
+            ("biPlanes", ctypes.wintypes.WORD),
+            ("biBitCount", ctypes.wintypes.WORD),
+            ("biCompression", ctypes.wintypes.DWORD),
+            ("biSizeImage", ctypes.wintypes.DWORD),
+            ("biXPelsPerMeter", ctypes.wintypes.LONG),
+            ("biYPelsPerMeter", ctypes.wintypes.LONG),
+            ("biClrUsed", ctypes.wintypes.DWORD),
+            ("biClrImportant", ctypes.wintypes.DWORD),
         ]
 
     BI_RGB = 0
@@ -57,15 +57,19 @@ if sys.platform.startswith('win32'):
     DeleteObject.argtypes = [ctypes.wintypes.HGDIOBJ]
 
     CreateDIBSection = ctypes.windll.gdi32.CreateDIBSection
-    CreateDIBSection.argtypes = [ctypes.wintypes.HDC, ctypes.c_void_p,
-                                 ctypes.c_uint,
-                                 ctypes.POINTER(ctypes.c_void_p),
-                                 ctypes.wintypes.HANDLE, ctypes.wintypes.DWORD]
+    CreateDIBSection.argtypes = [
+        ctypes.wintypes.HDC,
+        ctypes.c_void_p,
+        ctypes.c_uint,
+        ctypes.POINTER(ctypes.c_void_p),
+        ctypes.wintypes.HANDLE,
+        ctypes.wintypes.DWORD,
+    ]
     CreateDIBSection.restype = ctypes.wintypes.HBITMAP
 
     def serialize_dib(bi, pixels):
         bf = BITMAPFILEHEADER()
-        bf.bfType = 0x4d42
+        bf.bfType = 0x4D42
         bf.bfOffBits = ctypes.sizeof(bf) + bi.biSize
         bf.bfSize = bf.bfOffBits + bi.biSizeImage
         bf.bfReserved1 = bf.bfReserved2 = 0
@@ -75,17 +79,13 @@ if sys.platform.startswith('win32'):
         memcpy(bp, ctypes.byref(bf), ctypes.sizeof(bf))
         memcpy(bp + ctypes.sizeof(bf), ctypes.byref(bi), bi.biSize)
         memcpy(bp + bf.bfOffBits, pixels, bi.biSizeImage)
-        try:
-            return bytearray(buf)
-        except ValueError:
-            # py2.6
-            return buffer(buf)[:]
+        return bytearray(buf)
 
     class TestImageWinPointers(PillowTestCase):
         def test_pointer(self):
             im = hopper()
             (width, height) = im.size
-            opath = self.tempfile('temp.png')
+            opath = self.tempfile("temp.png")
             imdib = ImageWin.Dib(im)
 
             hdr = BITMAPINFOHEADER()
@@ -100,10 +100,10 @@ if sys.platform.startswith('win32'):
             hdr.biClrImportant = 0
 
             hdc = CreateCompatibleDC(None)
-            # print('hdc:',hex(hdc))
             pixels = ctypes.c_void_p()
-            dib = CreateDIBSection(hdc, ctypes.byref(hdr), DIB_RGB_COLORS,
-                                   ctypes.byref(pixels), None, 0)
+            dib = CreateDIBSection(
+                hdc, ctypes.byref(hdr), DIB_RGB_COLORS, ctypes.byref(pixels), None, 0
+            )
             SelectObject(hdc, dib)
 
             imdib.expose(hdc)
@@ -112,6 +112,3 @@ if sys.platform.startswith('win32'):
             DeleteDC(hdc)
 
             Image.open(BytesIO(bitmap)).save(opath)
-
-if __name__ == '__main__':
-    unittest.main()
