@@ -1,4 +1,4 @@
-from helper import unittest, PillowTestCase
+from .helper import unittest, PillowTestCase
 
 from PIL import __version__
 
@@ -10,7 +10,6 @@ except ImportError:
 
 @unittest.skipIf(pyroma is None, "Pyroma is not installed")
 class TestPyroma(PillowTestCase):
-
     def test_pyroma(self):
         # Arrange
         data = pyroma.projectdata.get_data(".")
@@ -19,16 +18,13 @@ class TestPyroma(PillowTestCase):
         rating = pyroma.ratings.rate(data)
 
         # Assert
-        if 'rc' in __version__:
-            # Pyroma needs to chill about RC versions
-            # and not kill all our tests.
-            self.assertEqual(rating, (9, [
-                "The package's version number does not comply with PEP-386."]))
+        if "rc" in __version__:
+            # Pyroma needs to chill about RC versions and not kill all our tests.
+            self.assertEqual(
+                rating,
+                (9, ["The package's version number does not comply with PEP-386."]),
+            )
 
         else:
             # Should have a perfect score
             self.assertEqual(rating, (10, []))
-
-
-if __name__ == '__main__':
-    unittest.main()
