@@ -40,7 +40,6 @@
 #define FLOOR(v) ((v) >= 0.0 ? (int) (v) : (int) floor(v))
 
 #define INK8(ink) (*(UINT8*)ink)
-#define INK32(ink) (*(INT32*)ink)
 
 /*
  * Rounds around zero (up=away from zero, down=torwards zero)
@@ -68,7 +67,12 @@ static inline void
 point8(Imaging im, int x, int y, int ink)
 {
     if (x >= 0 && x < im->xsize && y >= 0 && y < im->ysize)
-        im->image8[y][x] = (UINT8) ink;
+        if (strncmp(im->mode, "I;16", 4) == 0) {
+            im->image8[y][x*2] = (UINT8) ink;
+            im->image8[y][x*2+1] = (UINT8) ink;
+        } else {
+            im->image8[y][x] = (UINT8) ink;
+        }
 }
 
 static inline void
@@ -95,7 +99,7 @@ point32rgba(Imaging im, int x, int y, int ink)
 static inline void
 hline8(Imaging im, int x0, int y0, int x1, int ink)
 {
-    int tmp;
+    int tmp, pixelwidth;
 
     if (y0 >= 0 && y0 < im->ysize) {
         if (x0 > x1)
@@ -108,8 +112,11 @@ hline8(Imaging im, int x0, int y0, int x1, int ink)
             return;
         else if (x1 >= im->xsize)
             x1 = im->xsize-1;
-        if (x0 <= x1)
-            memset(im->image8[y0] + x0, (UINT8) ink, x1 - x0 + 1);
+        if (x0 <= x1) {
+            pixelwidth = strncmp(im->mode, "I;16", 4) == 0 ? 2 : 1;
+            memset(im->image8[y0] + x0 * pixelwidth, (UINT8) ink,
+                   (x1 - x0 + 1) * pixelwidth);
+        }
     }
 }
 
@@ -434,7 +441,7 @@ polygon_generic(Imaging im, int n, Edge *e, int ink, int eofill,
     }
 
     for (i = 0; i < n; i++) {
-        /* This causes that the pixels of horizontal edges are drawn twice :(
+        /* This causes the pixels of horizontal edges to be drawn twice :(
          * but without it there are inconsistencies in ellipses */
         if (e[i].ymin == e[i].ymax) {
             (*hline)(im, e[i].xmin, e[i].ymin, e[i].xmax, ink);
@@ -555,7 +562,7 @@ DRAW draw32rgba = { point32rgba, hline32rgba, line32rgba, polygon32rgba };
         ink = INK8(ink_);\
     } else {\
         draw = (op) ? &draw32rgba : &draw32;    \
-        ink = INK32(ink_);\
+        memcpy(&ink, ink_, sizeof(ink)); \
     }
 
 int
@@ -634,8 +641,9 @@ ImagingDrawWideLine(Imaging im, int x0, int y0, int x1, int y1,
 
 int
 ImagingDrawRectangle(Imaging im, int x0, int y0, int x1, int y1,
-                     const void* ink_, int fill, int op)
+                     const void* ink_, int fill, int width, int op)
 {
+    int i;
     int y;
     int tmp;
     DRAW* draw;
@@ -662,13 +670,16 @@ ImagingDrawRectangle(Imaging im, int x0, int y0, int x1, int y1,
             draw->hline(im, x0, y, x1, ink);
 
     } else {
-
         /* outline */
-        draw->line(im, x0, y0, x1, y0, ink);
-        draw->line(im, x1, y0, x1, y1, ink);
-        draw->line(im, x1, y1, x0, y1, ink);
-        draw->line(im, x0, y1, x0, y0, ink);
-
+        if (width == 0) {
+            width = 1;
+        }
+        for (i = 0; i < width; i++) {
+            draw->hline(im, x0, y0+i, x1, ink);
+            draw->hline(im, x0, y1-i, x1, ink);
+            draw->line(im, x1-i, y0, x1-i, y1, ink);
+            draw->line(im, x0+i, y1, x0+i, y0, ink);
+        }
     }
 
     return 0;
@@ -758,78 +769,42 @@ ellipsePoint(int cx, int cy, int w, int h,
 static int
 ellipse(Imaging im, int x0, int y0, int x1, int y1,
         float start, float end, const void* ink_, int fill,
-        int mode, int op)
+        int width, int mode, int op)
 {
     float i;
+    int inner;
     int n;
-    int cx, cy;
+    int maxEdgeCount;
     int w, h;
-    int x = 0, y = 0;
+    int x, y;
+    int cx, cy;
     int lx = 0, ly = 0;
     int sx = 0, sy = 0;
+    int lx_inner = 0, ly_inner = 0;
+    int sx_inner = 0, sy_inner = 0;
     DRAW* draw;
     INT32 ink;
-
-    w = x1 - x0;
-    h = y1 - y0;
-    if (w < 0 || h < 0)
-        return 0;
+    Edge* e;
 
     DRAWINIT();
 
-    cx = (x0 + x1) / 2;
-    cy = (y0 + y1) / 2;
-
     while (end < start)
         end += 360;
 
     if (end - start > 360) {
-        /* no need to go in loops */
+        // no need to go in loops
         end = start + 361;
     }
 
-    if (mode != ARC && fill) {
+    w = x1 - x0;
+    h = y1 - y0;
+    if (w <= 0 || h <= 0)
+        return 0;
 
-        /* Build edge list */
-        /* malloc check UNDONE, FLOAT? */
-        Edge* e = calloc((end - start + 3), sizeof(Edge));
-        if (!e) {
-            ImagingError_MemoryError();
-            return -1;
-        }
-
-        n = 0;
-
-        for (i = start; i < end+1; i++) {
-            if (i > end) {
-                i = end;
-            }
-            ellipsePoint(cx, cy, w, h, i, &x, &y);
-            if (i != start)
-                add_edge(&e[n++], lx, ly, x, y);
-            else
-                sx = x, sy = y;
-            lx = x, ly = y;
-        }
-
-        if (n > 0) {
-            /* close and draw polygon */
-            if (mode == PIESLICE) {
-                if (x != cx || y != cy) {
-                    add_edge(&e[n++], x, y, cx, cy);
-                    add_edge(&e[n++], cx, cy, sx, sy);
-                }
-            } else {
-                if (x != sx || y != sy)
-                    add_edge(&e[n++], x, y, sx, sy);
-            }
-            draw->polygon(im, n, e, ink, 0);
-        }
-
-        free(e);
-
-    } else {
+    cx = (x0 + x1) / 2;
+    cy = (y0 + y1) / 2;
 
+    if (!fill && width <= 1) {
         for (i = start; i < end+1; i++) {
             if (i > end) {
                 i = end;
@@ -853,6 +828,92 @@ ellipse(Imaging im, int x0, int y0, int x1, int y1,
                     draw->line(im, x, y, sx, sy, ink);
             }
         }
+    } else {
+        inner = (mode == ARC || !fill) ? 1 : 0;
+
+        // Build edge list
+        // malloc check UNDONE, FLOAT?
+        maxEdgeCount = end - start;
+        if (inner) {
+            maxEdgeCount *= 2;
+        }
+        maxEdgeCount += 3;
+        e = calloc(maxEdgeCount, sizeof(Edge));
+        if (!e) {
+            ImagingError_MemoryError();
+            return -1;
+        }
+
+        // Outer circle
+        n = 0;
+        for (i = start; i < end+1; i++) {
+            if (i > end) {
+                i = end;
+            }
+            ellipsePoint(cx, cy, w, h, i, &x, &y);
+            if (i == start) {
+                sx = x, sy = y;
+            } else {
+                add_edge(&e[n++], lx, ly, x, y);
+            }
+            lx = x, ly = y;
+        }
+        if (n == 0)
+            return 0;
+
+        if (inner) {
+            // Inner circle
+            x0 += width - 1;
+            y0 += width - 1;
+            x1 -= width - 1;
+            y1 -= width - 1;
+
+            w = x1 - x0;
+            h = y1 - y0;
+            if (w <= 0 || h <= 0) {
+                // ARC with no gap in the middle is a PIESLICE
+                mode = PIESLICE;
+                inner = 0;
+            } else {
+                for (i = start; i < end+1; i++) {
+                    if (i > end) {
+                        i = end;
+                    }
+                    ellipsePoint(cx, cy, w, h, i, &x, &y);
+                    if (i == start)
+                        sx_inner = x, sy_inner = y;
+                    else
+                        add_edge(&e[n++], lx_inner, ly_inner, x, y);
+                    lx_inner = x, ly_inner = y;
+                }
+            }
+        }
+
+        if (end - start < 360) {
+            // Close polygon
+            if (mode == PIESLICE) {
+                if (x != cx || y != cy) {
+                    add_edge(&e[n++], sx, sy, cx, cy);
+                    add_edge(&e[n++], cx, cy, lx, ly);
+                    if (inner) {
+                        ImagingDrawWideLine(im, sx, sy, cx, cy, &ink, width, op);
+                        ImagingDrawWideLine(im, cx, cy, lx, ly, &ink, width, op);
+                    }
+                }
+            } else if (mode == CHORD) {
+                add_edge(&e[n++], sx, sy, lx, ly);
+                if (inner) {
+                    add_edge(&e[n++], sx_inner, sy_inner, lx_inner, ly_inner);
+                }
+            } else if (mode == ARC) {
+                add_edge(&e[n++], sx, sy, sx_inner, sy_inner);
+                add_edge(&e[n++], lx, ly, lx_inner, ly_inner);
+            }
+        }
+
+        draw->polygon(im, n, e, ink, 0);
+
+        free(e);
     }
 
     return 0;
@@ -860,30 +921,32 @@ ellipse(Imaging im, int x0, int y0, int x1, int y1,
 
 int
 ImagingDrawArc(Imaging im, int x0, int y0, int x1, int y1,
-               float start, float end, const void* ink, int op)
+               float start, float end, const void* ink, int width, int op)
 {
-    return ellipse(im, x0, y0, x1, y1, start, end, ink, 0, ARC, op);
+    return ellipse(im, x0, y0, x1, y1, start, end, ink, 0, width, ARC, op);
 }
 
 int
 ImagingDrawChord(Imaging im, int x0, int y0, int x1, int y1,
-               float start, float end, const void* ink, int fill, int op)
+                 float start, float end, const void* ink, int fill,
+                 int width, int op)
 {
-    return ellipse(im, x0, y0, x1, y1, start, end, ink, fill, CHORD, op);
+    return ellipse(im, x0, y0, x1, y1, start, end, ink, fill, width, CHORD, op);
 }
 
 int
 ImagingDrawEllipse(Imaging im, int x0, int y0, int x1, int y1,
-                   const void* ink, int fill, int op)
+                   const void* ink, int fill, int width, int op)
 {
-    return ellipse(im, x0, y0, x1, y1, 0, 360, ink, fill, CHORD, op);
+    return ellipse(im, x0, y0, x1, y1, 0, 360, ink, fill, width, CHORD, op);
 }
 
 int
 ImagingDrawPieslice(Imaging im, int x0, int y0, int x1, int y1,
-                    float start, float end, const void* ink, int fill, int op)
+                    float start, float end, const void* ink, int fill,
+                    int width, int op)
 {
-    return ellipse(im, x0, y0, x1, y1, start, end, ink, fill, PIESLICE, op);
+    return ellipse(im, x0, y0, x1, y1, start, end, ink, fill, width, PIESLICE, op);
 }
 
 /* -------------------------------------------------------------------- */
